@@ -1,6 +1,6 @@
 import os
 import pytest
-from typing import Callable, Any
+from typing import Callable
 from abc import ABC, abstractmethod
 
 
@@ -29,7 +29,6 @@ class AbstractCLIResult(ABC):
         return equal_exit_code and equal_stdout and equal_stderr
 
 
-
 @pytest.fixture
 def production_template():
     import cookiecutter_python as cpp
